is_valid_option_key

Function is_valid_option_key 

fn is_valid_option_key(key: &str) -> bool
Check whether key is a valid identifier for a profile [options] entry.

Keys must start with an ASCII letter or underscore, followed by any number of ASCII letters, digits, or underscores. Empty keys are rejected.